==> small-0.2.0.tgz: package/release/parser.js <==
/// <reference path="../definitions/ref.d.ts" />
var ts = require('typescript');
var node_1 = require('./node');
var Parser = (function () {
    function Parser() {
    }
    Parser.prototype.parse = function (file) {
        var ast = ts.createSourceFile(file.filename, file.source, 2 /* Latest */);
        file.ast = ast;
        var host = {
            getSourceFile: function (fileName, languageVersion) {
                if (fileName === file.filename)
                    return ast;
            },
            getDefaultLibFileName: function (options) { return ''; },
            writeFile: function () { },
            getCurrentDirectory: function () { return ''; },
            getCanonicalFileName: function (fileName) { return fileName; },
            useCaseSensitiveFileNames: function () { return true; },
            getNewLine: function () { return '\n\r'; },
            fileExists: function (fileName) { return fileName === file.filename; },
            readFile: function (fileName) { return fileName === file.filename ? file.source : undefined; }
        };
        var program = ts.createProgram([file.filename], { noResolve: true, noEmit: true, target: 2 /* Latest */, allowNonTsExtensions: true }, host);
        var typeChecker = program.getTypeChecker();
        var walker = new Walker();
        var importNodes = [];
        var exportNodes = [];
        // Find import & export nodes.
        walker.walk(ast, function (child) {
            var importNode = node_1.ImportNode.tryParse(typeChecker, child);
            if (importNode) {
                importNodes.push(importNode);
                // Don't descend
                return;
            }
            var exportNode = node_1.ExportNode.tryParse(typeChecker, child, walker.isInFunction);
            if (exportNode) {
                exportNodes.push(exportNode);
                if (exportNode.assignmentValue)
                    walker.descend(exportNode.assignmentValue);
                return;
            }
            walker.descend();
        });
        // Find import references
        walker.walk(ast, function (child) {
            var reference = node_1.ImportReference.tryParse(typeChecker, importNodes, child);
            if (reference) {
                reference.importNode.references.push(reference);
            }
            else {
                walker.descend();
            }
        });
        file.importNodes = importNodes;
        file.exportNodes = exportNodes;
    };
    return Parser;
})();
exports.Parser = Parser;
var Walker = (function () {
    function Walker() {
        this.node = undefined;
        this.isConditional = false;
        this.isInFunction = false;
    }
    Walker.prototype.walk = function (node, callback) {
        this.callback = callback;
        this.visit(node);
    };
    Walker.prototype.visit = function (node) {
        var saveNode = this.node;
        var saveIsConditional = this.isConditional;
        var saveIsInFunction = this.isInFunction;
        this.node = node;
        switch (node.kind) {
            case 211 /* FunctionDeclaration */:
            case 171 /* FunctionExpression */:
            case 212 /* ClassDeclaration */:
            case 184 /* ClassExpression */:
                this.isConditional = true;
                this.isInFunction = true;
                break;
        }
        if (!this.isConditional && node.parent) {
            switch (node.parent.kind) {
                case 194 /* IfStatement */:
                    if (node === node.parent.thenStatement || node === node.parent.elseStatement) {
                        this.isConditional = true;
                    }
                    break;
                case 197 /* ForStatement */:
                case 199 /* ForOfStatement */:
                case 198 /* ForInStatement */:
                case 196 /* WhileStatement */:
                case 195 /* DoStatement */:
                    if (node.parent.statement === node) {
                        this.isConditional = true;
                    }
                    break;
                case 179 /* BinaryExpression */:
                    var expression = node.parent;
                    if (expression.operatorToken.kind === 50 /* AmpersandAmpersandToken */
                        || expression.operatorToken.kind === 51 /* BarBarToken */) {
                        if (expression.right === node) {
                            this.isConditional = true;
                        }
                    }
                    break;
            }
        }
        this.callback(node);
        this.node = saveNode;
        this.isConditional = saveIsConditional;
        this.isInFunction = saveIsInFunction;
    };
    Walker.prototype.descend = function (node) {
        var _this = this;
        if (node === void 0) { node = this.node; }
        ts.forEachChild(node, function (child) { return _this.visit(child); });
    };
    return Walker;
})();

==> small-0.2.2.tgz: package/release/parser.js <==
/// <reference path="../definitions/ref.d.ts" />
var ts = require('typescript');
var node_1 = require('./node');
var Parser = (function () {
    function Parser() {
    }
    Parser.prototype.parse = function (file) {
        var ast = ts.createSourceFile(file.filename, file.source, 2 /* Latest */);
        file.ast = ast;
        var host = {
            getSourceFile: function (fileName, languageVersion) {
                if (fileName === file.filename)
                    return ast;
            },
            getDefaultLibFileName: function (options) { return ''; },
            writeFile: function () { },
            getCurrentDirectory: function () { return ''; },
            getCanonicalFileName: function (fileName) { return fileName; },
            useCaseSensitiveFileNames: function () { return true; },
            getNewLine: function () { return '\n\r'; },
            fileExists: function (fileName) { return fileName === file.filename; },
            readFile: function (fileName) { return fileName === file.filename ? file.source : undefined; }
        };
        var program = ts.createProgram([file.filename], { noResolve: true, noEmit: true, target: 2 /* Latest */, allowNonTsExtensions: true, noLib: true }, host);
        var typeChecker = program.getTypeChecker();
        var walker = new Walker();
        var importNodes = [];
        var exportNodes = [];
        // Find import & export nodes.
        walker.walk(ast, function (child) {
            var importNode = node_1.ImportNode.tryParse(typeChecker, child);
            if (importNode) {
                importNodes.push(importNode);
                // Don't descend
                return;
            }
            var exportNode = node_1.ExportNode.tryParse(typeChecker, child, walker.isInFunction);
            if (exportNode) {
                exportNodes.push(exportNode);
                if (exportNode.assignmentValue)
                    walker.descend(exportNode.assignmentValue);
                return;
            }
            walker.descend();
        });
        // Find import references
        walker.walk(ast, function (child) {
            var reference = node_1.ImportReference.tryParse(typeChecker, importNodes, child);
            if (reference) {
                reference.importNode.references.push(reference);
            }
            else {
                walker.descend();
            }
        });
        file.importNodes = importNodes;
        file.exportNodes = exportNodes;
    };
    return Parser;
})();
exports.Parser = Parser;
var Walker = (function () {
    function Walker() {
        this.node = undefined;
        this.isConditional = false;
        this.isInFunction = false;
    }
    Walker.prototype.walk = function (node, callback) {
        this.callback = callback;
        this.visit(node);
    };
    Walker.prototype.visit = function (node) {
        var saveNode = this.node;
        var saveIsConditional = this.isConditional;
        var saveIsInFunction = this.isInFunction;
        this.node = node;
        switch (node.kind) {
            case 213 /* FunctionDeclaration */:
            case 173 /* FunctionExpression */:
            case 214 /* ClassDeclaration */:
            case 186 /* ClassExpression */:
                this.isConditional = true;
                this.isInFunction = true;
                break;
        }
        if (!this.isConditional && node.parent) {
            switch (node.parent.kind) {
                case 196 /* IfStatement */:
                    if (node === node.parent.thenStatement || node === node.parent.elseStatement) {
                        this.isConditional = true;
                    }
                    break;
                case 199 /* ForStatement */:
                case 201 /* ForOfStatement */:
                case 200 /* ForInStatement */:
                case 198 /* WhileStatement */:
                case 197 /* DoStatement */:
                    if (node.parent.statement === node) {
                        this.isConditional = true;
                    }
                    break;
                case 181 /* BinaryExpression */:
                    var expression = node.parent;
                    if (expression.operatorToken.kind === 51 /* AmpersandAmpersandToken */
                        || expression.operatorToken.kind === 52 /* BarBarToken */) {
                        if (expression.right === node) {
                            this.isConditional = true;
                        }
                    }
                    break;
            }
        }
        this.callback(node);
        this.node = saveNode;
        this.isConditional = saveIsConditional;
        this.isInFunction = saveIsInFunction;
    };
    Walker.prototype.descend = function (node) {
        var _this = this;
        if (node === void 0) { node = this.node; }
        ts.forEachChild(node, function (child) { return _this.visit(child); });
    };
    return Walker;
})();
